pikepdf API Reference
*********************

Primary objects
===============

.. autoclass:: pikepdf.Pdf
    :members:

.. autofunction:: pikepdf.open

.. autoclass:: pikepdf.Object
    :members:

.. autoexception:: pikepdf.PdfError


Support
=======

.. autoclass:: pikepdf.PdfMatrix

.. autoclass:: pikepdf.PdfImage
    :members:

.. autoclass:: pikepdf.PdfInlineImage
    :members:
